function [p_hat,sigma,Ta,T0] = htestprop1(altype,alpha,p0,k,n)

//Hypothesis testing on one proportion
//altype = 'one' for one-sided alternative hypothesis
//altype = 'two' for two-sided alternative hypothesis
//alpha  = significance level (typical values = 0.01,0.05,0.10)
//p0     = value being tested
//k      = number of successes out of n trials
//Estimate of the proportion is k/n

if altype<>'one' & altype<>'two' then
   error('htestmu1 - select type of alternative hypothesis = one or two');
   abort;
end;

printf(' \n');
printf('Hypothesis testing on one proportion: ' ...
       + altype + '-side alternative hypothesis.\n')
printf(' \n');

p_hat = k/n;
sigma = sqrt(p_hat*(1-p_hat)/n);
T0 = (p_hat-p0)/sigma;

if n>=30 & altype=='one' then
   Ta = cdfnor('X',0,1,1-alpha,alpha);
   printf('Test parameter used: z');
elseif n>=30 & altype=='two' then
   Ta = cdfnor('X',0,1,1-alpha/2,alpha/2);
   printf('Test parameter used: z');
elseif n<30 & altype=='one' then
   Ta = cdft('T',n-1,1-alpha,alpha);
   printf('Test parameter used: t');
else
   Ta = cdft('T',n-1,1-alpha/2,alpha/2);
   printf('Test parameter used: t');
end;

if altype == 'two' then
   if T0>Ta | T0<-Ta then
      printf('Reject the null hypothesis H0 : p = %f\n',p0);
   else
      printf('Do not reject the null hypothesis H0 : p = %f\n',p0);
   end
else
  if T0>Ta then
     printf('Reject the null hypothesis H0 : p = %f\n',p0);
     printf('if the alternative hypothesis is H1 : p > %f\n',p0);
  elseif T0<-Ta
     printf('Reject the null hypothesis H0 : p = %f\n',p0);
     printf('if the alternative hypothesis is H1 : p < %f\n',p0);
  else
     printf('Do not reject the null hypothesis H0 : p = %f\n',p0);
  end
end;
printf(' \n');
endfunction
