function [x] = secantm(x0,dx,f)

//|-------------------------------------------|
//|Secant-type method applied to a            |
//| system of linear equations f(x) = 0,      |
//| given the jacobian function J, with       |
//| The Jacobian built by columns.            |
//| x = [x1;x2;...;xn], f = [f1;f2;...;fn]    |
//| x0 is the initial guess of the solution   |
//| dx is an increment in x1,x2,... variables |
//|-------------------------------------------|


N = 100;             //define max. number of iterations
epsilon = 1.0e-10;   //define tolerance
maxval = 10000.0;    //define value for divergence

if abs(dx)<epsilon then
	error('dx = 0, use different values');
	abort;
end;

xn  = x0;           //load initial guess

[n m] = size(x0);

while (N>0)
	JJ = int(10*rand(n,n));
        xx = zeros(n,1);
	for j = 1:n				//Estimating
		xx = xn;			//Jacobian by
		xx(j) = xn(j) + dx;		//finite
		JJ(:,j) = (f(xx)-f(xn))/dx;	//differences
	end;					//by columns
//pause 
	if abs(det(JJ))<epsilon then
		error('newtonm - Jacobian is singular - try new x0,dx');
		abort;
	end;

	xnp1 = xn - inv(JJ)*f(xn);

	if abs(f(xnp1))<epsilon then
		x=xnp1;
		disp(100-N); 
		return(xnp1);
	end;

	if abs(f(xnp1))>maxval then
		disp(100-N);
		error('Solution diverges');
		abort;
	end;

	N = N - 1;
	xn  = xnp1;
end;
error('No convergence');

end function
